@@ -1,3 +1,6 @@
 from .base import create_app, create_app_wsgi
-
+from . import panel
 __all__ = ["create_app", "create_app_wsgi"]
+
+# application = create_app_wsgi()
+
